/*
	do file for reference only. ycls_full.dta contains the full set of variables
	used in the analysis.

*/
loc end  = 12 

forvalues w = 1/`end' {
	
	tempfile temp_`w'
	insheet using "`indir'\rawdata\ycls_week`w'.csv", comma clear

	di in red "Week: `w'"
	
		// State
			gen d_state = state	
			replace d_state = "" if inlist(d_state, "NA")
		
		// Age
			cap confirm numeric variable age
			if _rc != 0 gen d_age = real(age)
			else gen d_age = age
			
			gen x_age_bin_0 = missing(d_age)
			gen x_age_bin_1 = d_age < 25
			gen x_age_bin_2 = inrange(d_age, 25, 34)
			gen x_age_bin_3 = inrange(d_age, 35, 44)
			gen x_age_bin_4 = inrange(d_age, 45, 54) // Note this is where the modal person is
			gen x_age_bin_5 = inrange(d_age, 55, 65)
			gen x_age_bin_6 = d_age > 65
			label var d_age "Respondent Age"
			
		// Education
			encode lucid_education, gen(d_educ) 
			recode d_educ (10=1) (5 9 = 2) (1 3 7 = 3) (2=4) (4 6 = 5) (8 = 6)
			cap label drop edulab
			label define edulab 1 "< High School" 2 "High School/GED" 3 " Associate's/Some College" ///
				4 "Bachelor's Degree" 5 "Graduate Degree" 6 "Other"
			label var d_educ "Respondent Education Level [1-5]"
			label values d_educ edulab
			tab d_educ, gen(x_educ_) 
			
		// Region (string in week 1/2, num in 3+)
			if `w' < 3 encode region, gen(d_region)
			if `w' > 2 gen d_region = region 
			cap label drop reglab
			label define reglab 1 "Northeast" 2 "Midwest" 3 "South" 4 "West" 5 "Other"
			label var d_region "US Region"
			label values d_region reglab
			tab d_region, gen(x2_region_)
			
		// Gender
			gen d_female = lucid_gender == "Female"
			label var d_female "Respondent Gender, Female [1 = Yes]"
		
		// HHI
			encode lucid_hhi, gen(d_hhi)
			recode d_hhi (3 24 = 1) (6 8 = 2) (10/12 = 3) (13/15 = 4) (16/19=5) (20/23=6) ///
				(1/2 = 7) (4/5 = 8) (7/9 = 9) (* = 99)
			cap label drop hhilab
			label define hhilab 1 "<$20,000" 2 "$20,000-$29,999" 3 "$30,000-$44,999" ///
				4 "$45,000-$59,999" 5 "$60,000-$79,999" 6 "$80,000-$99,999" 7 "$100,000-$149,999" ///
				8 "$150,000-$199,999" 9 "$200,000+"
			label values d_hhi hhilab
			label var d_hhi "HH Income [Scale 1-9]"
			tab d_hhi, gen(x_hhi_)
			replace d_hhi = . if d_hhi == 99
			
		// Party 
			cap confirm string variable lucid_pid_7n
			if _rc != 0 {
				cap drop temp
				gen temp = string(lucid_pid_7n)
				drop lucid_pid_7n
				rename temp lucid_pid_7n
			} 
			gen d_dem = inlist(lucid_pid_7n, "1", "2", "3")
			gen d_dem_str = inlist(lucid_pid_7n, "1", "2")
			gen d_gop = inlist(lucid_pid_7n, "5", "6", "7")
			gen d_gop_str = inlist(lucid_pid_7n, "7", "6")
			gen d_ind_pure = lucid_pid_7n == "4"
			gen d_ind_lean = inlist(lucid_pid_7n, "3", "5", "4")
			
			label var d_dem "Respondent PID, Democrat (Incl. Leaners)"
			label var d_gop "Respondent PID, Republican (Incl. Leaners)"
			label var d_ind_pure "Respondent PID, Pure Independent"
			label var d_dem_str "Respondent PID, Democrats (Excl. Leaners)"
			label var d_gop_str "Respondent PID, Republicans (Excl. Leaners)"
			label var d_ind_lean "Respondent PID, Independents (Pure + Leaners)"
			
			gen d_pid = "Democrat" if d_dem == 1
			replace d_pid = "Republican" if d_gop == 1
			replace d_pid = "Independent" if d_ind_pure == 1
			
			// PID 7
			gen d_pid_7 = real(lucid_pid_7n)
			cap label drop pid7lab
			label define pid7lab 1 "Strong Democrat" 2 "Weak Democrat" 3 "Lean Democrat" ///
				4 "Independent" 5 "Lean Republican" 6 "Weak Republican" 7 "Strong Republican"
			label values d_pid_7 pid7lab
			label var d_pid_7 "Respondent PID, 7-pt Scale"
			replace d_pid_7 = 99 if missing(d_pid_7)
			tab d_pid_7, gen(pid7_)
			replace d_pid_7 = . if d_pid_7 == 99
		
		// Race (Use Lucid's coding)
			gen lucid_race = "White" if lucid_ethnicity == "White"
			replace lucid_race = "Asian" if strpos(lucid_ethnicity, "Asian") != 0
			replace lucid_race = "Black" if strpos(lucid_ethnicity, "Black") != 0
			replace lucid_race = "Other" if missing(lucid_race)
			
			gen d_white = lucid_race == "White"
			label var d_white "White [1 = Yes]"
			gen d_asian = lucid_race == "Asian"
			label var d_asian "Asian [1 = Yes]"
			gen d_black = strpos(lucid_race, "Black") != 0
			label var d_black "Black [1 = Yes]"
			gen d_raceother = d_white != 1 & d_black != 1 & d_asian != 1
			
			cap confirm numeric var lucid_hispanic
			if _rc != 0 gen d_hispanic = lucid_hispanic == "1" 
			else gen d_hispanic = lucid_hispanic == 1
			label var d_hispanic "Hispanic [1 = Yes]"
			
	// Political 
		// 2016 vote
		gen vote16_gop = strpos(pol_vote16, "Republican") != 0
		gen vote16_dem = strpos(pol_vote16, "Democrat") != 0
		gen vote16_oth = strpos(pol_vote16, "Other") != 0
		gen vote16_abs = strpos(pol_vote16, "did not") != 0
		gen vote16 = "Democrat" if vote16_dem == 1
		replace vote16 = "Republican" if vote16_gop == 1
		replace vote16 = "Didn't Vote" if strpos(pol_vote16, "did not")
		replace vote16 = "Other" if strpos(pol_vote16, "Other")
		replace vote16 = "NA" if inlist(pol_vote16, "NA")
		label var vote16_gop "Voted Republican in 2016"
		label var vote16_dem "Voted Democrat in 2016"
		label var vote16_oth "Voted Other in 2016"
		label var vote16_abs "Abstention in 2016"
		label var vote16 "2016 Vote"
		
		// 2020 vote (multiple codings)
		gen vote20_gop = strpos(postad_vote, "Republican") != 0
		gen vote20_dem = strpos(postad_vote, "Democrat") != 0
		gen vote20_oth = strpos(postad_vote, "Other") != 0
		gen vote20_abs = strpos(postad_vote, "not vote") != 0
		gen vote20 = "Democrat" if vote20_dem == 1
		replace vote20 = "Republican" if vote20_gop == 1
		replace vote20 = "Didn't Vote" if strpos(postad_vote, "not vote") != 0
		replace vote20 = "Other" if strpos(postad_vote, "Other") != 0
		replace vote20 = "NA" if strpos(postad_vote, "NA") != 0
		label var vote20_gop "Vote Republican in 2020"
		label var vote20_dem "Vote Democrat in 2020"
		label var vote20_oth "Vote Other in 2020"
		label var vote20_abs "Abstention in 2020"
		label var vote20 "2020 Vote"
		
		// Republican Vote Intention
		gen vote20_gopdem = .
		replace vote20_gopdem = 1 if vote20 == "Republican"
		replace vote20_gopdem = -1 if vote20 == "Democrat"
		replace vote20_gopdem = 0 if vote20 == "Didn't Vote" | vote20 == "Abstain"
		label var vote20_gopdem "2020 Intended Vote, -1 = Dem, 0 = Abs, 1 = Rep"
		
	// Employment	
		replace dem_emp_past = "Other" if dem_emp_past == "NA" 
		replace dem_emp_current = "Other" if dem_emp_current == "NA" 
		
		cap drop employ_past
		gen employ_past = dem_emp_past
		replace employ_past = "Not in LF" if inlist(dem_emp_past, "Other", "Permanently disabled", ///
			"Retired", "Student") | strpos(dem_emp_past, "Taking care of home") != 0
		
		cap drop employ_curr
		gen employ_curr = dem_emp_current
		replace employ_curr = "Not in LF" if inlist(dem_emp_current, "Other", "Permanently disabled", ///
			"Retired", "Student") | strpos(dem_emp_current, "Taking care of home") != 0
			
		label var employ_past "Employment on Jan 1"
		label var employ_curr "Employment at time of survey"
		
		// Employment gradient
		gen job_change = 1 if employ_past == "Working part time" & employ_curr == "Working full time" 
		replace job_change = 1 if inlist(employ_past, "Temporarily laid off", "Unemployed", "Not in LF") ///
			& employ_curr == "Working part time"
		replace job_change = 2 if inlist(employ_past, "Temporarily laid off", "Unemployed", "Not in LF") ///
			& employ_curr == "Working full time"
		replace job_change = -1 if employ_past == "Working full time" & employ_curr == "Working part time" 
		replace job_change = -2 if employ_past == "Working full time" & ///
			inlist(employ_curr, "Temporarily laid off", "Not in LF", "Unemployed")
		replace job_change = -1 if employ_past == "Working part time" & ///
			inlist(employ_curr, "Temporarily laid off", "Not in LF", "Unemployed") ///
			
		replace job_change = 0 if employ_past == employ_curr
		replace job_change = 0 if missing(job_change)
			
		label var job_change "Magnitude of job change (-2, 2)"
	
		// Employment dummy
		gen job_improve = job_change > 0
		gen job_worse = job_change < 0
		gen job_same = job_change == 0
	
		// Employment industry
		rename dem_industry_recent_1 jlv_industry_jan1
		replace jlv_industry_jan1 = "" if jlv_industry_jan1 == "NA"
		label var jlv_industry_jan1 "Industry, on Jan 1"
		
		// Industry dummies
		replace jlv_industry_jan1 = "None" if missing(jlv_industry_jan1) // So that we can dummy even if missing	
		replace jlv_industry_curr = "None" if missing(jlv_industry_curr)
		gen jlv_industry = jlv_industry_curr
		replace jlv_industry = jlv_industry_jan1 if jlv_industry_curr == "None" 
		
		label var jlv_industry "Most recent industry of employment"
		label var jlv_industry_curr "Current industry of employment (only if currently employed)"
		label var jlv_industry_jan1 "Industry of employment in Jan 1 (only if lost job)"
		
		
	// Clean up 
		rename responseid d_Qid // Qualtrics ID (rid is lucid id)
		label var d_Qid "Respondent ID (Qualtrics)"
		rename rid d_Lid // Lucid ID
		label var d_Lid "Respondent ID (Lucid)"
		if `w' <= 3 keep d_* x* vote* employ* jlv* pid7* dem_emp_current dem_emp_past job_*
		else keep d_* x* vote* employ* jlv* pid7* dem_emp_current dem_emp_past job_*
		
		gen week = `w'
		if `w' != `end' save `temp_`w'', replace
}
	
	// Append all the temp files
	loc z = `end'-1

	forvalues x = 1/`z' {
		di in red "Appending Week `x'"
		append using `temp_`x''
	}
	
	// Week specific edits
		replace x_age_bin_0 = 0 if missing(x_age_bin_0)
		replace x_educ_6 = 0 if missing(x_educ_6)
		replace x2_region_5 = 0 if missing(x2_region_5)
		replace pid7_8 = 0 if missing(pid7_8)

	// Clean up missings
		drop if missing(vote20_gop)
		drop if missing(d_pid)
		drop if missing(vote20_gopdem)
		drop if vote16 == "NA" | vote20 == "NA" // missing values
		drop if missing(d_white) & missing(d_asian) & missing(d_black) & missing(d_hispanic)
		// Drop first response of duplicate lucid ID
			bys d_Lid: gen n = _n
			drop if n == 2
			drop n
			
	// Deanonymize IDs
		drop d_Lid d_Qid
		gen r_id = _n
	
	save13 `dir'/data/ycls_full.dta, replace 
