/*
	Replication file for Appendix Tables A1 and A2.
*/

// Set directories
	cd "C:\Users\[filename]\Replication"
	loc dir "C:\Users\[filename]\Replication"

	use `dir'/ycls_full.dta, clear

	
	// Table A1. Survey Demographics (gender, , race, pid, employed, 	
		preserve

			gen x_female = d_female
			gen x_race_asian = d_asian
			gen x_race_white = d_white
			gen x_race_black = d_black
			gen x_race_hisp = d_hispanic
			gen x_pid_dem = d_dem
			gen x_pid_gop = d_gop
			gen x_pid_ind = d_ind_pure
			
			foreach v of varlist x* {
				loc var = subinstr("`v'", "x_", "", .)
				gen i_`var' = `v' if job_improve == 1 // because these are all binary, we can create sums by collapsing
				gen w_`var' = `v' if job_change == -2
				gen o_`var' = `v' if job_change == 0
			}
			gen tot_i = job_improve==1
			gen tot_w = job_change == -2
			gen tot_o = job_change == 0
			collapse (sum) i_* w_* o_* tot_*
			gen i = .
		
			foreach v of varlist i_* {
				replace `v'  = `v'/tot_i
			}
			foreach v of varlist w_* {
				replace `v'  = `v'/tot_w
			}
			foreach v of varlist o_* {
				replace `v'  = `v'/tot_o
			}
			rename tot_w w_tot
			rename tot_i i_tot
			rename tot_o o_tot
			reshape long o_ i_ w_, i(i) j(x) s
			drop i
		
			drop if x == "age_bin_0" // delete if people don't give age
			drop if x == "region_5"
			
			gen order = .
			gen temp = substr(x, 1, 3)
			replace order = 1 if temp == "fem"
			replace order = 2 if temp == "rac"
			replace order = 3 if temp == "age"
			replace order = 4 if temp == "edu"
			replace order = 5.5 if temp == "emp"
			replace order = 8 if temp == "pid"
			
			gen suborder = real(substr(x, -1, 1))
			replace suborder = 1 if x == "race_white"
			replace suborder = 2 if x == "race_asian"
			replace suborder = 3 if x == "race_black"
			replace suborder = 1 if x == "emp_yes"
			replace suborder = 2 if x == "emp_no"
			replace suborder = 1 if x == "pid_dem"
			replace suborder = 2 if x == "pid_gop"
			
			sort order suborder
			drop order suborder temp
			
			// Age
			replace x = "< 25 years old" if x == "age_bin_1"
			replace x = "25-34 years old" if x == "age_bin_2"
			replace x = "35-44 years old" if x == "age_bin_3"
			replace x = "45-54 years old" if x == "age_bin_4"
			replace x = "55-65 years old" if x == "age_bin_5"
			replace x = "> 65 years old" if x == "age_bin_6"
			// Education
			replace x = "Some high school" if x == "educ_1"
			replace x = "High school diploma/GED" if x == "educ_2"
			replace x = "Associate's Degree/Some College" if x == "educ_3"
			replace x = "Bachelor's Degree" if x == "educ_4"
			replace x = "Graduate Degree" if x == "educ_5"
			replace x = "Other" if x == "educ_6"
			// Income
			replace x = "< $20,000" if x == "hhi_1"
			replace x = "$20,000 - $29,999" if x == "hhi_2"
			replace x = "$30,000 - $44,999" if x == "hhi_3"
			replace x = "$45,000 - $59,999" if x == "hhi_4"
			replace x = "$60,000 - $79,999" if x == "hhi_5"
			replace x = "$80,000 - $99,999" if x == "hhi_6"
			replace x = "$100,000 - $149,999" if x == "hhi_7"
			replace x = "$150,000 - $199,999" if x == "hhi_8"
			replace x = "$200,000+" if x == "hhi_9"
			replace x = "Prefer not to say" if x == "hhi_10"
			// Gender, Race, PID
			replace x = "Female" if x == "female"
			replace x = "White" if x == "race_white"
			replace x = "Asian" if x == "race_asian"
			replace x = "Black" if x == "race_black"
			replace x = "Hispanic/Latino" if x == "race_hisp"
			replace x = "Democrats (w/ leaners)" if x == "pid_dem"
			replace x = "Republicans (w/ leaners)" if x == "pid_gop"
			replace x = "Independents" if x == "pid_ind"
		
			list
			outsheet using `dir'/table_A1.csv, comma replace
		restore

		
		
// Table A2. Crosstab of 2016 vote and job change
	tab job_change, gen(change)
	gen vote16_absoth = vote16_abs == 1 | vote16_oth ==1
	
	foreach v in gop dem absoth {
		forvalues c = 1/5 {
			gen n_`v'_`c' = change`c' == 1 & vote16_`v' == 1
		}
	}
	
	collapse (sum) n_*
		
	gen i = .
	reshape long n_dem_ n_gop_ n_absoth_, i(i) j(change)
	drop i
		
	outsheet using `dir'/table_A2.csv, comma replace
	
